"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Common = void 0;
const chalk = require("chalk");
const fs_extra_1 = require("fs-extra");
const path_1 = require("path");
const pod_config_1 = require("../../pod.config");
class Common {
    constructor() {
        this.configFile = '';
        this.config = {};
        this.projectPath = '';
        this.fileType = '';
        this.filePath = '';
        this.fileName = '';
    }
    async setup(projectPath, args) {
        const [type, file] = args;
        if (!type || !file) {
            this.throwInvalidateError();
        }
        this.projectPath = projectPath;
        this.fileType = type;
        const { fileName } = this.setFileInfo(file);
        await this.setConfig(fileName);
        this.validateType(type);
    }
    async setConfig(fileName, silence = false) {
        let configMethod;
        let file;
        const configFilePath = 'pod.config.js';
        try {
            file = `${this.projectPath}/${configFilePath}`;
            configMethod = await Promise.resolve().then(() => require(file));
        }
        catch (e) {
            file = 'default';
            configMethod = pod_config_1.defaultConfigMethod;
        }
        this.configFile = file;
        this.config = configMethod(fileName);
        if (!silence) {
            const msg = (file === 'default') ? 'Using default config...' : `Using config: ${file}`;
            this.log('info', msg);
        }
        return this.config;
    }
    setFileInfo(path) {
        const split = path.split('/');
        const fileName = split[split.length - 1];
        split.pop();
        const filePath = split.join('/');
        this.filePath = filePath;
        this.fileName = fileName;
        return { filePath, fileName };
    }
    validateType(type) {
        const types = Object.keys(this.config);
        if (!types.includes(type)) {
            this.log('error', `Invalid type '${type}' requested. Allowed types: [${types.join(',')}]`);
            process.exit();
        }
    }
    constructFilePath(file, customFileLoc) {
        let fileDir = `.`;
        if (file.basepath) {
            fileDir += `/${file.basepath}`;
        }
        const fileLoc = customFileLoc || this.filePath;
        if (fileLoc) {
            fileDir += `/${fileLoc}`;
        }
        const filename = `${file.filename}.${file.extension}`;
        const filePath = `${fileDir}/${filename}`;
        return { fileDir, filename, filePath };
    }
    log(type, msg) {
        let coloredMsg;
        switch (type) {
            case 'info':
                coloredMsg = chalk.blue(msg);
                break;
            case 'error':
                coloredMsg = chalk.red(msg);
                break;
            case 'success':
                coloredMsg = chalk.greenBright(msg);
                break;
            case 'warning':
                coloredMsg = chalk.yellowBright(msg);
                break;
        }
        console.log(coloredMsg);
    }
    throwInvalidateError() {
        this.log('error', 'Arguments missing, try vue-cli-service help');
        process.exit();
    }
    getRelativePath(templateFilePath, filePath) {
        const rPath = path_1.relative(templateFilePath, filePath);
        return rPath.includes('/') ? rPath : `./${rPath}`;
    }
    deleteDir(dirpath) {
        const paths = dirpath.split('/');
        let fullpath = dirpath;
        while (paths.length) {
            try {
                fs_extra_1.rmdirSync(fullpath);
                paths.pop();
                fullpath = paths.join('/');
            }
            catch (e) {
                break;
            }
        }
    }
}
exports.Common = Common;
